## Changes

<!-- Include a description of what changed -->

## Do you want to deploy these changes as a new version?

- [ ] Yes
  - [ ] I updated the version number in `project.toml`
  - [ ] I followed [Semantic Versioning](https://semver.org/) to update the version number
- [ ] No
  - [x] Leave the version number as it is

## Did you add new dependencies?

- [ ] Yes
  - [ ] I updated the `dependencies` section in `pyproject.toml`
- [ ] No
  - [x] Leave the `dependencies` section as it is
